@@ -13,7 +13,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Constructor.
 sub new {
@@ -294,7 +294,7 @@ Returns instance of object.
 
 =item * C<css>
 
-'CSS::Struct::Output' object for L<process_css> processing.
+L<CSS::Struct::Output> object for L<process_css> processing.
 
 Default value is undef.
 
@@ -332,13 +332,13 @@ Default value is undef.
 
 =item * C<tags>
 
-'Tags::Output' object.
+L<Tags::Output> object.
 
 Default value is undef.
 
 =item * C<text>
 
-Hash reference with keys defined language in ISO 639-3 code and value with hash
+Hash reference with keys defined language in ISO 639-2 code and value with hash
 reference with texts.
 
 Required keys are 'login', 'password_label', 'username_label' and 'submit'.
@@ -593,6 +593,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
